%define major		0
%define libname		%mklibname storj %{major}
%define develname	%mklibname storj -d

Name:		libstorj
Version:	1.0.3
Release:	%mkrel 5
Summary:	Client library and CLI for encrypted file transfer on the Storj network
Group:		System/Libraries
License:	LGPLv2+
URL:		https://storj.io/
Source0:	https://github.com/Storj/libstorj/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	gcc
BuildRequires:	pkgconfig(json-c)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libmicrohttpd)
BuildRequires:	pkgconfig(libuv)

%description
Asynchronous multi-platform C client library and CLI for encrypted file
transfer on the Storj network.

Feature Highlights:

  * Asynchronous I/O with concurrent peer-to-peer network requests for
    shards
  * Erasure encoding with reed solomon for data durability
  * Robust handling of shard transfers by selecting alternative sources
  * File integrity and authenticity verified with HMAC-SHA512
  * File encryption with AES-256-CTR
  * File name and bucket name encryption with AES-256-GCM
  * Proxy support with SOCKS5, SOCKS4, SOCKS4a
  * Asynchronous progress updates in bytes per file
  * Transfers can be cleanly canceled per file
  * Seed based file encryption key for portability between devices
  * Reference implementation for SIP5 file standard

#------------------------------------------------

%package -n	%{libname}
Summary:	Client library and CLI for encrypted file transfer on the Storj network
Group:		System/Libraries

%description -n	%{libname}
Asynchronous multi-platform C client library and CLI for encrypted file
transfer on the Storj network.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Asynchronous multi-platform C client library and CLI for encrypted file
transfer on the Storj network.

This package contains files needed to compile code using %{name}.

#------------------------------------------------

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure --disable-static
%make_build

%install
%make_install

# we don't want these
find %{buildroot} -name '*.la' -delete

%files
%license LICENSE
%doc README.md
%{_bindir}/storj

%files -n %{libname}
%license LICENSE
%doc README.md
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc README.md
%{_includedir}/*
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Sun Nov 29 2020 luigiwalser <luigiwalser> 1.0.3-5.mga8
+ Revision: 1650432
- rebuild for nettle

* Sun Nov 29 2020 luigiwalser <luigiwalser> 1.0.3-4.mga8
+ Revision: 1650341
- rebuild for json-c

* Sun Feb 16 2020 umeabot <umeabot> 1.0.3-3.mga8
+ Revision: 1534262
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 01 2019 daviddavid <daviddavid> 1.0.3-2.mga8
+ Revision: 1448571
- rebuild for new nettle 3.5.1

* Mon Dec 31 2018 daviddavid <daviddavid> 1.0.3-1.mga7
+ Revision: 1347346
- new version: 1.0.3

* Mon Aug 27 2018 daviddavid <daviddavid> 1.0.2-2.mga7
+ Revision: 1254931
- rebuild for new json-c 0.13.1

* Wed Oct 25 2017 daviddavid <daviddavid> 1.0.2-1.mga7
+ Revision: 1173747
- initial package libstorj

